# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetMedicalStudy(BaseModel):
    medical_study: Optional["GetMedicalStudyMedicalStudy"] = Field(alias="medicalStudy")


class GetMedicalStudyMedicalStudy(BaseModel):
    id: str
    name: str
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    creation_date: Any = Field(alias="creationDate")
    thing: Optional[str]
    relevance: Optional[float]
    address: Optional["GetMedicalStudyMedicalStudyAddress"]


class GetMedicalStudyMedicalStudyAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


GetMedicalStudy.model_rebuild()
GetMedicalStudyMedicalStudy.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryMedicalContraindications(BaseModel):
    medical_contraindications: Optional[
        "QueryMedicalContraindicationsMedicalContraindications"
    ] = Field(alias="medicalContraindications")


class QueryMedicalContraindicationsMedicalContraindications(BaseModel):
    results: Optional[
        List[Optional["QueryMedicalContraindicationsMedicalContraindicationsResults"]]
    ]


class QueryMedicalContraindicationsMedicalContraindicationsResults(BaseModel):
    id: str
    name: str
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    creation_date: Any = Field(alias="creationDate")
    thing: Optional[str]
    relevance: Optional[float]


QueryMedicalContraindications.model_rebuild()
QueryMedicalContraindicationsMedicalContraindications.model_rebuild()
